@@ -1,7 +1,7 @@
 ################################################################################
 # BSD LICENSE
 #
-# Copyright(c) 2019-2022 Intel Corporation. All rights reserved.
+# Copyright(c) 2019-2023 Intel Corporation. All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -47,8 +47,9 @@ from pqos.mba import PqosMba
 from pqos.allocation import PqosAlloc
 from pqos.cpuinfo import PqosCpuInfo
 
-import common
-import log
+from appqos import common
+from appqos import log
+from appqos.manager import MANAGER
 
 
 class PqosApi:
@@ -57,8 +58,43 @@ class PqosApi:
     Wrapper for libpqos wrapper.
     """
 
+    _instance = None
+    pqos = None
+
+    @classmethod
+    def set_instance(cls, instance):
+        "Sets an instance of this class."
+
+        cls._instance = instance
+
+    @classmethod
+    def get_instance(cls):
+        "Gets an instance of this class."
+
+        return cls._instance
+
+    def __new__(cls):
+        """
+        Returns an object of this class if already created
+        or constructs a new one.
+        """
+
+        instance = cls.get_instance()
+
+        # if instance is None:
+        #     instance = object.__new__(cls)
+        #     cls.set_instance(instance)
+
+        if instance is None:
+            instance = object.__new__(cls)
+            cls.set_instance(instance)
+
+        return cls.get_instance()
 
     def __init__(self):
+        if self.pqos is not None:
+            return
+
         self.pqos = Pqos()
         self.cap = None
         self.l3ca = None
@@ -66,31 +102,16 @@ class PqosApi:
         self.mba = None
         self.alloc = None
         self.cpuinfo = None
-        self._supported_iface = []
 
         # dict to share interface type and MBA BW status
         # between REST API process and "backend"
-        self.shared_dict = common.MANAGER.dict()
+        self.shared_dict = MANAGER.dict()
         self.shared_dict['current_iface'] = None
         self.shared_dict['mba_bw_supported'] = None
         self.shared_dict['mba_bw_enabled'] = None
 
 
-    def detect_supported_ifaces(self):
-        """
-        Detects supported RDT interfaces
-        """
-        for iface in ["msr","os"]:
-            if not self.init(iface, True):
-                log.info(f"Interface {iface.upper()}, " \
-                         f"MBA BW: {'un' if not self.is_mba_bw_supported() else ''}supported.")
-                self.fini()
-                self._supported_iface.append(iface)
-
-        log.info("Supported RDT interfaces: " + str(self.supported_iface()))
-
-
-    def init(self, iface, force_iface = False):
+    def init(self, iface):
         """
         Initializes libpqos
 
@@ -99,10 +120,6 @@ class PqosApi:
             -1 otherwise
         """
 
-        if not force_iface and not iface in self.supported_iface():
-            log.error(f"RDT does not support '{iface}' interface!")
-            return -1
-
         # deinitialize lib first
         if self.shared_dict['current_iface']:
             self.fini()
@@ -174,18 +191,6 @@ class PqosApi:
         return self.shared_dict['current_iface']
 
 
-    def supported_iface(self):
-        """
-        Returns list of supported RDT interfaces
-
-        Returns:
-            list of supported interfaces
-        """
-        # no need to keep it in shared dict as it does not changed
-        # during runtime.
-        return self._supported_iface
-
-
     def is_mba_bw_supported(self):
         """
         Returns MBA BW support status
@@ -214,16 +219,29 @@ class PqosApi:
             0 on success
             -1 otherwise
         """
+        return self.reset(mba_cfg = "ctrl" if enable else "default")
+
+
+    def reset(self, l3_cdp_cfg = "any", l2_cdp_cfg = "any", mba_cfg = "any"):
+        """
+        Reset configuration and set RDT features enabled status
+
+        Returns:
+            0 on success
+            -1 otherwise
+        """
+
         try:
             # call libpqos alloc reset
-            self.alloc.reset("any", "any", "ctrl" if enable else "default")
+            self.alloc.reset(l3_cdp_cfg, l2_cdp_cfg, mba_cfg)
         except Exception as ex:
             log.error("libpqos reset(..) call failed!")
             log.error(str(ex))
             return -1
 
         # Reread MBA BW status from libpqos
-        self.refresh_mba_bw_status()
+        if mba_cfg != "any":
+            self.refresh_mba_bw_status()
 
         return 0
 
@@ -286,21 +304,23 @@ class PqosApi:
         return 0
 
 
-    def l3ca_set(self, sockets, cos_id, ways_mask):
+    def l3ca_set(self, sockets, cos_id, mask=None, code_mask=None, data_mask=None):
         """
         Configures L3 CAT for CoS
 
         Parameters:
             sockets: sockets list on which to configure L3 CAT
             cos_id: Class of Service
-            ways_mask: L3 CAT CBM to set
+            mask: L3 CAT CBM to set
+            code_mask: L3 CAT code CBM to set
+            data_mask: L3 CAT data CBM to set
 
         Returns:
             0 on success
             -1 otherwise
         """
         try:
-            cos = self.l3ca.COS(cos_id, ways_mask)
+            cos = self.l3ca.COS(cos_id, mask=mask, code_mask=code_mask, data_mask=data_mask)
             for socket in sockets:
                 self.l3ca.set(socket, [cos])
         except Exception as ex:
@@ -309,7 +329,7 @@ class PqosApi:
 
         return 0
 
-    def l2ca_set(self, l2ids, cos_id, ways_mask):
+    def l2ca_set(self, l2ids, cos_id, mask=None, code_mask=None, data_mask=None):
         """
         Configures L2 CAT for CoS
 
@@ -317,13 +337,15 @@ class PqosApi:
             l2ids: L2 cache identifiers list on which to configure L2 CAT
             cos_id: Class of Service
             ways_mask: L2 CAT CBM to set
+            code_mask: L2 CAT code CBM to set
+            data_mask: L2 CAT data CBM to set
 
         Returns:
             0 on success
             -1 otherwise
         """
         try:
-            cos = self.l2ca.COS(cos_id, ways_mask)
+            cos = self.l2ca.COS(cos_id, mask=mask, code_mask=code_mask, data_mask=data_mask)
             for l2id in l2ids:
                 self.l2ca.set(l2id, [cos])
         except Exception as ex:
@@ -724,6 +746,26 @@ class PqosApi:
             log.error(str(ex))
             return None
 
+    def get_l3_non_contiguous_cbm(self):
+        # pylint: disable=no-self-use
+        """
+        Gets L3 cache non-contiguous cbm
+
+        Returns:
+            L3 cache non-contiguous cbm
+            or None on error
+        """
+
+        if not self.is_l3_cat_supported():
+            return None
+
+        try:
+            l3ca_caps = self.cap.get_type("l3ca")
+            return l3ca_caps.non_contiguous_cbm
+        except Exception as ex:
+            log.error(str(ex))
+            return None
+
     def get_l2_cache_size(self):
         # pylint: disable=no-self-use
         """
@@ -825,3 +867,25 @@ class PqosApi:
         except Exception as ex:
             log.error(str(ex))
             return None
+
+    def get_l2_non_contiguous_cbm(self):
+        # pylint: disable=no-self-use
+        """
+        Gets L2 cache non-contiguous cbm
+
+        Returns:
+            L2 cache non-contiguous cbm
+            or None on error
+        """
+
+        if not self.is_l2_cat_supported():
+            return None
+
+        try:
+            l2ca_caps = self.cap.get_type("l2ca")
+            return l2ca_caps.non_contiguous_cbm
+        except Exception as ex:
+            log.error(str(ex))
+            return None
+
+PQOS_API = PqosApi()
