@@ -1,7 +1,7 @@
 ################################################################################
 # BSD LICENSE
 #
-# Copyright(c) 2019-2021 Intel Corporation. All rights reserved.
+# Copyright(c) 2019-2023 Intel Corporation. All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -30,13 +30,18 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ################################################################################
 
+"""
+Unit tests for appqos.cache_ops module
+"""
+
 import pytest
 import mock
 
-import common
-
-from cache_ops import *
+from appqos import common
+from appqos.cache_ops import *
+from appqos.config import Config
 
+@mock.patch("appqos.caps.caps_get", mock.MagicMock(return_value=[]))
 def test_configure_rdt():
     Pool.pools[1] = {}
     Pool.pools[1]['cores'] = [1, 101]
@@ -48,26 +53,28 @@ def test_configure_rdt():
     Pool.pools[2]['cbm'] = 0x200
     Pool.pools[2]['mba'] = 22
 
-    with mock.patch('common.CONFIG_STORE.get_pool_attr', return_value=[1]) as mock_get_pool_attr,\
-         mock.patch('cache_ops.Pool.cores_set') as mock_cores_set,\
-         mock.patch('cache_ops.Pool.configure', return_value=0) as mock_pool_configure,\
-         mock.patch('cache_ops.Apps.configure', return_value=0) as mock_apps_configure,\
-         mock.patch('common.PQOS_API.init', return_value=0),\
-         mock.patch('common.PQOS_API.enable_mba_bw', return_value=0),\
-         mock.patch('common.CONFIG_STORE.recreate_default_pool', return_value=0):
+    with mock.patch('appqos.config.Config.get_pool_attr', return_value=[1]) as mock_get_pool_attr,\
+         mock.patch('appqos.cache_ops.Pool.cores_set') as mock_cores_set,\
+         mock.patch('appqos.cache_ops.Pool.configure', return_value=0) as mock_pool_configure,\
+         mock.patch('appqos.cache_ops.Apps.configure', return_value=0) as mock_apps_configure,\
+         mock.patch('appqos.pqos_api.PQOS_API.init', return_value=0),\
+         mock.patch('appqos.pqos_api.PQOS_API.enable_mba_bw', return_value=0),\
+         mock.patch('appqos.config_store.ConfigStore.recreate_default_pool', return_value=0):
 
-        assert not configure_rdt()
+        cfg = Config({})
+
+        assert not configure_rdt(cfg)
 
         mock_cores_set.assert_called_once_with([])
         mock_pool_configure.assert_called_once()
         mock_apps_configure.assert_called_once()
 
         mock_pool_configure.return_value = -1
-        assert configure_rdt() == -1
+        assert configure_rdt(cfg) == -1
 
         mock_pool_configure.return_value = 0
         mock_get_pool_attr.return_value = []
-        assert configure_rdt() == -1
+        assert configure_rdt(cfg) == -1
 
 
 class TestPools(object):
@@ -79,13 +86,15 @@ class TestPools(object):
     ## @endcond
 
 
-    @mock.patch("caps.cat_l3_supported", mock.MagicMock(return_value=True))
-    @mock.patch("caps.mba_supported", mock.MagicMock(return_value=True))
+    @mock.patch("appqos.caps.cat_l3_supported", mock.MagicMock(return_value=True))
+    @mock.patch("appqos.caps.cat_l2_supported", mock.MagicMock(return_value=True))
+    @mock.patch("appqos.caps.mba_supported", mock.MagicMock(return_value=True))
     def test_configure(self):
-        def get_attr(attr, pool_id):
+        def get_attr(cls, attr, pool_id):
             config = {
                 'cores': [1, 2],
-                'cbm': 15,
+                'l3cbm': 15,
+                'l2cbm': 7,
                 'mba': 88,
                 'apps': [1],
                 'pids': [11, 22]
@@ -96,41 +105,187 @@ class TestPools(object):
             else:
                 return None
 
-        with mock.patch('common.CONFIG_STORE.get_pool_attr', new=get_attr),\
-             mock.patch('common.CONFIG_STORE.get_app_attr', new=get_attr),\
-             mock.patch('cache_ops.Pool.cbm_set') as mock_cbm_set,\
-             mock.patch('cache_ops.Pool.mba_set') as mock_mba_set,\
-             mock.patch('cache_ops.Pool.cores_set') as mock_cores_set,\
-             mock.patch('cache_ops.Pool.pids_set') as mock_pids_set,\
-             mock.patch('cache_ops.Pool.apply') as mock_apply:
+        with mock.patch('appqos.config.Config.get_pool_attr', new=get_attr),\
+             mock.patch('appqos.config.Config.get_app_attr', new=get_attr),\
+             mock.patch('appqos.cache_ops.Pool.l3cbm_set') as mock_l3cbm_set,\
+             mock.patch('appqos.cache_ops.Pool.l2cbm_set') as mock_l2cbm_set,\
+             mock.patch('appqos.cache_ops.Pool.mba_set') as mock_mba_set,\
+             mock.patch('appqos.cache_ops.Pool.cores_set') as mock_cores_set,\
+             mock.patch('appqos.cache_ops.Pool.pids_set') as mock_pids_set,\
+             mock.patch('appqos.cache_ops.Pool.apply') as mock_apply:
 
-             Pool(1).configure()
+             Pool(1).configure(Config({}))
 
-             mock_cbm_set.assert_called_once_with(15)
+             mock_l3cbm_set.assert_called_once_with(15)
+             mock_l2cbm_set.assert_called_once_with(7)
              mock_mba_set.assert_called_once_with(88)
              mock_cores_set.assert_called_once_with([1,2])
-             mock_pids_set.assert_called_once_with([11,22])
+             mock_pids_set.assert_called_once_with([11,22], get_attr(None, 'cores', 0))
              mock_apply.assert_called_once_with(1)
 
 
-    def test_cbm_get(self):
+        def get_attr(cls, attr, pool_id):
+            config = {
+                'cores': [1, 2],
+                'l3cbm_code': 3,
+                'l3cbm_data': 12,
+                'l2cbm_code': 3,
+                'l2cbm_data': 4,
+                'mba_bw': 100,
+                'apps': [1],
+                'pids': [11, 22]
+            }
+
+            if attr in config:
+                return config[attr]
+            else:
+                return None
+
+        with mock.patch('appqos.config.Config.get_pool_attr', new=get_attr),\
+             mock.patch('appqos.config.Config.get_app_attr', new=get_attr),\
+             mock.patch('appqos.config.Config.get_l2cdp_enabled', mock.MagicMock(return_value=True)),\
+             mock.patch('appqos.config.Config.get_l3cdp_enabled', mock.MagicMock(return_value=True)),\
+             mock.patch("appqos.caps.mba_bw_enabled", mock.MagicMock(return_value=True)),\
+             mock.patch('appqos.cache_ops.Pool.l3cbm_set_code') as mock_l3cbm_set_code,\
+             mock.patch('appqos.cache_ops.Pool.l3cbm_set_data') as mock_l3cbm_set_data,\
+             mock.patch('appqos.cache_ops.Pool.l2cbm_set_code') as mock_l2cbm_set_code,\
+             mock.patch('appqos.cache_ops.Pool.l2cbm_set_data') as mock_l2cbm_set_data,\
+             mock.patch('appqos.cache_ops.Pool.mba_bw_set') as mock_mba_bw_set,\
+             mock.patch('appqos.cache_ops.Pool.cores_set') as mock_cores_set,\
+             mock.patch('appqos.cache_ops.Pool.pids_set') as mock_pids_set,\
+             mock.patch('appqos.cache_ops.Pool.apply') as mock_apply:
+
+             Pool(1).configure(Config({}))
+
+             mock_l3cbm_set_code.assert_called_once_with(3)
+             mock_l3cbm_set_data.assert_called_once_with(12)
+             mock_l2cbm_set_code.assert_called_once_with(3)
+             mock_l2cbm_set_data.assert_called_once_with(4)
+             mock_l2cbm_set.assert_called_once_with(7)
+             mock_mba_bw_set.assert_called_once_with(100)
+             mock_cores_set.assert_called_once_with([1,2])
+             mock_pids_set.assert_called_once_with([11,22], get_attr(None, 'cores', 0))
+             mock_apply.assert_called_once_with(1)
+
+
+    def test_l3cbm_get(self):
         Pool.pools[3] = {}
-        Pool.pools[3]['cbm'] = 0xf
+        Pool.pools[3]['l3cbm'] = 0xf
         Pool.pools[1] = {}
 
-        assert Pool(3).cbm_get() == 0xf
-        assert not Pool(1).cbm_get()
-        assert not Pool(2).cbm_get()
+        assert Pool(3).l3cbm_get() == 0xf
+        assert not Pool(1).l3cbm_get()
+        assert not Pool(2).l3cbm_get()
 
 
-    def test_cbm_set(self):
+    def test_l3cbm_get_code(self):
         Pool.pools[3] = {}
-        Pool.pools[3]['cbm'] = 0xf
+        Pool.pools[3]['l3cbm_code'] = 0xf
         Pool.pools[1] = {}
 
-        Pool(3).cbm_set(0x1)
+        assert Pool(3).l3cbm_get_code() == 0xf
+        assert not Pool(1).l3cbm_get_code()
+        assert not Pool(2).l3cbm_get_code()
 
-        assert 0x1 == Pool.pools[3]['cbm']
+
+    def test_l3cbm_get_data(self):
+        Pool.pools[3] = {}
+        Pool.pools[3]['l3cbm_data'] = 0xf
+        Pool.pools[1] = {}
+
+        assert Pool(3).l3cbm_get_data() == 0xf
+        assert not Pool(1).l3cbm_get_data()
+        assert not Pool(2).l3cbm_get_data()
+
+
+    def test_l3cbm_set(self):
+        Pool.pools[3] = {}
+        Pool.pools[3]['l3cbm'] = 0xf
+        Pool.pools[1] = {}
+
+        Pool(3).l3cbm_set(0x1)
+
+        assert 0x1 == Pool.pools[3]['l3cbm']
+
+
+    def test_l3cbm_set_code(self):
+        Pool.pools[3] = {}
+        Pool.pools[3]['l3cbm_code'] = 0xf
+        Pool.pools[1] = {}
+
+        Pool(3).l3cbm_set_code(0x1)
+
+        assert 0x1 == Pool.pools[3]['l3cbm_code']
+
+
+    def test_l3cbm_set_data(self):
+        Pool.pools[3] = {}
+        Pool.pools[3]['l3cbm_data'] = 0xf
+        Pool.pools[1] = {}
+
+        Pool(3).l3cbm_set_data(0x1)
+
+        assert 0x1 == Pool.pools[3]['l3cbm_data']
+
+
+    def test_l2cbm_get(self):
+        Pool.pools[3] = {}
+        Pool.pools[3]['l2cbm'] = 0xf
+        Pool.pools[1] = {}
+
+        assert Pool(3).l2cbm_get() == 0xf
+        assert not Pool(1).l2cbm_get()
+        assert not Pool(2).l2cbm_get()
+
+
+    def test_l2cbm_get_code(self):
+        Pool.pools[3] = {}
+        Pool.pools[3]['l2cbm_code'] = 0xf
+        Pool.pools[1] = {}
+
+        assert Pool(3).l2cbm_get_code() == 0xf
+        assert not Pool(1).l2cbm_get_code()
+        assert not Pool(2).l2cbm_get_code()
+
+
+    def test_l2cbm_get_data(self):
+        Pool.pools[3] = {}
+        Pool.pools[3]['l2cbm_data'] = 0xf
+        Pool.pools[1] = {}
+
+        assert Pool(3).l2cbm_get_data() == 0xf
+        assert not Pool(1).l2cbm_get_data()
+        assert not Pool(2).l2cbm_get_data()
+
+
+    def test_l2cbm_set(self):
+        Pool.pools[3] = {}
+        Pool.pools[3]['l2cbm'] = 0xf
+        Pool.pools[1] = {}
+
+        Pool(3).l2cbm_set(0x1)
+
+        assert 0x1 == Pool.pools[3]['l2cbm']
+
+
+    def test_l2cbm_set_code(self):
+        Pool.pools[3] = {}
+        Pool.pools[3]['l2cbm_code'] = 0xf
+        Pool.pools[1] = {}
+
+        Pool(3).l2cbm_set_code(0x1)
+
+        assert 0x1 == Pool.pools[3]['l2cbm_code']
+
+
+    def test_l2cbm_set_data(self):
+        Pool.pools[3] = {}
+        Pool.pools[3]['l2cbm_data'] = 0xf
+        Pool.pools[1] = {}
+
+        Pool(3).l2cbm_set_data(0x1)
+
+        assert 0x1 == Pool.pools[3]['l2cbm_data']
 
 
     def test_mba_get(self):
@@ -174,14 +329,16 @@ class TestPools(object):
         Pool.pools[30] = {}
         Pool.pools[30]['pids'] = [3, 30, 3030]
 
-        with mock.patch('common.CONFIG_STORE.get_pool_attr', return_value=[1, 44, 66]),\
-             mock.patch('cache_ops.set_affinity') as set_aff_mock:
-            Pool(1).pids_set([1, 10])
+        with mock.patch('appqos.cache_ops.set_affinity') as set_aff_mock:
+
+            default_cores = [1, 44, 66]
+
+            Pool(1).pids_set([1, 10], default_cores)
 
             set_aff_mock.assert_called_once_with([1010], [1, 44, 66])
             set_aff_mock.reset_mock()
 
-            Pool(30).pids_set([30, 3030])
+            Pool(30).pids_set([30, 3030], default_cores)
 
             set_aff_mock.assert_called_once_with([3], [1, 44, 66])
 
@@ -197,8 +354,9 @@ class TestPools(object):
         assert Pool(35).cores_get() == [3, 30, 33]
 
 
-    @mock.patch('common.PQOS_API.alloc_assoc_set')
-    @mock.patch('common.PQOS_API.release')
+    @mock.patch('appqos.pqos_api.PQOS_API.alloc_assoc_set')
+    @mock.patch('appqos.pqos_api.PQOS_API.release')
+    @mock.patch('appqos.caps.caps_get', mock.MagicMock(return_value=[]))
     def test_cores_set(self, mock_release, mock_alloc_assoc_set):
         Pool.pools[1] = {}
         Pool.pools[1]['cores'] = []
@@ -215,8 +373,8 @@ class TestPools(object):
         mock_release.assert_called_once_with([2])
 
 
-    @mock.patch('common.PQOS_API.l3ca_set')
-    @mock.patch('common.PQOS_API.alloc_assoc_set')
+    @mock.patch('appqos.pqos_api.PQOS_API.l3ca_set')
+    @mock.patch('appqos.pqos_api.PQOS_API.alloc_assoc_set')
     def test_apply_not_configured(self, mock_l3ca_set, mock_alloc_assoc_set):
         result = Pool.apply(1)
 
@@ -226,26 +384,46 @@ class TestPools(object):
         mock_alloc_assoc_set.assert_not_called()
 
 
-    @mock.patch('common.PQOS_API.mba_set')
-    @mock.patch('common.PQOS_API.l3ca_set')
-    @mock.patch('common.PQOS_API.alloc_assoc_set')
-    @mock.patch('common.PQOS_API.get_sockets')
-    @mock.patch('common.CONFIG_STORE.get_mba_ctrl_enabled')
-    def test_apply(self, mock_get_mba_ctrl_enabled, mock_get_socket, mock_alloc_assoc_set, mock_l3ca_set, mock_mba_set):
+    @mock.patch('appqos.pqos_api.PQOS_API.is_l2_cdp_enabled')
+    @mock.patch('appqos.pqos_api.PQOS_API.is_l3_cdp_enabled')
+    @mock.patch('appqos.pqos_api.PQOS_API.mba_set')
+    @mock.patch('appqos.pqos_api.PQOS_API.l2ca_set')
+    @mock.patch('appqos.pqos_api.PQOS_API.l3ca_set')
+    @mock.patch('appqos.pqos_api.PQOS_API.alloc_assoc_set')
+    @mock.patch('appqos.pqos_api.PQOS_API.get_sockets')
+    @mock.patch('appqos.pqos_api.PQOS_API.get_l2ids')
+    @mock.patch('appqos.config.Config.get_mba_ctrl_enabled')
+    def test_apply(self, mock_get_mba_ctrl_enabled, mock_get_l2ids, mock_get_socket, \
+        mock_alloc_assoc_set, mock_l3ca_set, mock_l2ca_set, mock_mba_set, \
+        mock_is_l3_cdp_enabled, mock_is_l2_cdp_enabled):
+
+        Pool.pools[3] = {}
+        Pool.pools[3]['cores'] = [5, 6]
+        Pool.pools[3]['l3cbm_code'] = 0x800
+        Pool.pools[3]['l3cbm_data'] = 0x400
+        Pool.pools[3]['l2cbm_code'] = 0xc
+        Pool.pools[3]['l2cbm_data'] = 0x3
+
         Pool.pools[2] = {}
         Pool.pools[2]['cores'] = [1]
-        Pool.pools[2]['cbm'] = 0xc00
+        Pool.pools[2]['l3cbm'] = 0xc00
+        Pool.pools[2]['l2cbm'] = 0xf
         Pool.pools[2]['mba'] = 99
 
         Pool.pools[1] = {}
         Pool.pools[1]['cores'] = [2, 3]
-        Pool.pools[1]['cbm'] = 0x300
+        Pool.pools[1]['l3cbm'] = 0x300
+        Pool.pools[1]['l2cbm'] = 0xff
         Pool.pools[1]['mba'] = 11
 
         mock_alloc_assoc_set.return_value = 0
         mock_mba_set.return_value = 0
         mock_l3ca_set.return_value = 0
+        mock_l2ca_set.return_value = 0
+        mock_is_l2_cdp_enabled.return_value = False
+        mock_is_l3_cdp_enabled.return_value = False
         mock_get_socket.return_value = [0, 2]
+        mock_get_l2ids.return_value = [0, 1]
         mock_get_mba_ctrl_enabled.return_value = False
 
         result = Pool.apply(2)
@@ -255,8 +433,10 @@ class TestPools(object):
 
         mock_mba_set.assert_any_call([0, 2], 2, 99, False)
         mock_mba_set.assert_any_call([0, 2], 1, 11, False)
-        mock_l3ca_set.assert_any_call([0, 2], 2, 0xc00)
-        mock_l3ca_set.assert_any_call([0, 2], 1, 0x300)
+        mock_l3ca_set.assert_any_call([0, 2], 2, mask=0xc00)
+        mock_l3ca_set.assert_any_call([0, 2], 1, mask=0x300)
+        mock_l2ca_set.assert_any_call([0, 1], 1, mask=0xff)
+        mock_l2ca_set.assert_any_call([0, 1], 2, mask=0xf)
         mock_alloc_assoc_set.assert_any_call([1], 2)
         mock_alloc_assoc_set.assert_any_call([2, 3], 1)
 
@@ -289,6 +469,14 @@ class TestPools(object):
         result = Pool.apply(1)
         assert result != 0
 
+        mock_l2ca_set.return_value = -1
+        mock_mba_set.return_value = 0
+        result = Pool.apply(2)
+        assert result != 0
+        result = Pool.apply(1)
+        assert result != 0
+
+        mock_l2ca_set.return_value = 0
         mock_alloc_assoc_set.return_value = -1
         mock_l3ca_set.return_value = -1
         result = Pool.apply(2)
@@ -296,6 +484,27 @@ class TestPools(object):
         result = Pool.apply(1)
         assert result != 0
 
+        #cdp
+        mock_alloc_assoc_set.return_value = 0
+        mock_mba_set.return_value = 0
+        mock_l3ca_set.return_value = 0
+        mock_l2ca_set.return_value = 0
+        mock_is_l2_cdp_enabled.return_value = True
+        mock_is_l3_cdp_enabled.return_value = True
+        mock_get_socket.return_value = [0, 2]
+        mock_get_l2ids.return_value = [0, 1]
+        mock_get_mba_ctrl_enabled.return_value = False
+
+        result = Pool.apply(3)
+        assert result == 0
+
+        mock_l3ca_set.return_value = -1
+        result = Pool.apply(3)
+        assert result != 0
+
+        mock_l2ca_set.return_value = -1
+        result = Pool.apply(3)
+        assert result != 0
 
     def test_reset(self):
         Pool.pools[2] = {}
@@ -332,30 +541,30 @@ class TestApps(object):
             }
         ]}
 
-        def get_pool_attr(attr, pool_id):
+        def get_pool_attr(cls, attr, pool_id):
             if attr == 'cores':
                 return [1, 2, 3, 4]
             else:
                 return None
 
-        with mock.patch('common.CONFIG_STORE.get_config', return_value={}),\
-             mock.patch('common.CONFIG_STORE.app_to_pool') as atp_mock,\
-             mock.patch('common.CONFIG_STORE.get_pool_attr') as gpa_mock,\
-             mock.patch('cache_ops.set_affinity') as sa_mock:
+        with mock.patch('appqos.config.Config.app_to_pool') as atp_mock,\
+             mock.patch('appqos.config.Config.get_pool_attr') as gpa_mock,\
+             mock.patch('appqos.cache_ops.set_affinity') as sa_mock:
 
-                Apps.configure()
+                cfg = Config({})
+                Apps.configure(cfg)
 
                 atp_mock.assert_not_called()
                 gpa_mock.assert_not_called()
                 sa_mock.assert_not_called()
 
 
-        with mock.patch('common.CONFIG_STORE.get_config', return_value=CONFIG),\
-             mock.patch('common.CONFIG_STORE.app_to_pool', return_value=1),\
-             mock.patch('common.CONFIG_STORE.get_pool_attr', new=get_pool_attr),\
-             mock.patch('cache_ops.set_affinity') as set_aff_mock:
+        with mock.patch('appqos.config.Config.app_to_pool', return_value=1),\
+             mock.patch('appqos.config.Config.get_pool_attr', new=get_pool_attr),\
+             mock.patch('appqos.cache_ops.set_affinity') as set_aff_mock:
 
-                Apps.configure()
+                cfg = Config(CONFIG)
+                Apps.configure(cfg)
 
                 set_aff_mock.assert_any_call([1], [1])
                 set_aff_mock.assert_any_call([2, 22], [2])
