@@ -1,7 +1,7 @@
 ################################################################################
 # BSD LICENSE
 #
-# Copyright(c) 2019-2021 Intel Corporation. All rights reserved.
+# Copyright(c) 2019-2023 Intel Corporation. All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -30,13 +30,28 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ################################################################################
 
+"""
+Unit tests for appqos.sstbf module
+"""
+
 import mock
 import pytest
 
-import sstbf
+from appqos import sstbf
+from appqos.config import Config
 
+try:
+    import pwr
 
+    HAS_PWR = True
+except ImportError:
+    HAS_PWR = False
+
+@pytest.mark.skipif(not HAS_PWR, reason="pwr package not installed")
 def test_is_sstbf_enabled():
+    """
+    Tests sstbf.is_sstbf_enabled()
+    """
     class SYS:
         def __init__(self, enabled):
             self.sst_bf_enabled = enabled
@@ -58,7 +73,11 @@ def test_is_sstbf_enabled():
         mock_get_system.assert_called_once()
 
 
+@pytest.mark.skipif(not HAS_PWR, reason="pwr package not installed")
 def test_is_sstbf_configured():
+    """
+    Tests sstbf.is_sstbf_configured()
+    """
     class SYS:
         def __init__(self, configured):
             self.sst_bf_configured = configured
@@ -87,8 +106,11 @@ def test_is_sstbf_configured():
         mock_get_system.assert_called_once()
 
 
+@pytest.mark.skipif(not HAS_PWR, reason="pwr package not installed")
 def test_configure_sstbf():
-
+    """
+    Tests sstbf.configure_sstbf()
+    """
     sys = mock.MagicMock()
     sys.commit = mock.MagicMock()
 
@@ -109,7 +131,11 @@ def test_configure_sstbf():
         mock_get_sys.assert_called_once()
 
 
+@pytest.mark.skipif(not HAS_PWR, reason="pwr package not installed")
 def test_get_hp_cores():
+    """
+    Tests sstbf.get_hp_cores()
+    """
     cores = []
     for i in range(0, 11):
         core = mock.MagicMock()
@@ -125,15 +151,19 @@ def test_get_hp_cores():
     for ret_val in [None, []]:
         sstbf.HP_CORES = None
         with mock.patch("pwr.get_cores", return_value=ret_val) as mock_get_cores:
-            assert sstbf.get_hp_cores() == None
+            assert sstbf.get_hp_cores() is None
 
     sstbf.HP_CORES = None
     with mock.patch("pwr.get_cores", side_effect = IOError('Test')) as mock_get_cores:
-        assert sstbf.get_hp_cores() == None
+        assert sstbf.get_hp_cores() is None
         mock_get_cores.assert_called_once()
 
 
+@pytest.mark.skipif(not HAS_PWR, reason="pwr package not installed")
 def test_get_std_cores():
+    """
+    Tests sstbf.get_std_cores()
+    """
     cores = []
     for i in range(0, 11):
         core = mock.MagicMock()
@@ -149,21 +179,24 @@ def test_get_std_cores():
     for ret_val in [None, []]:
         sstbf.STD_CORES = None
         with mock.patch("pwr.get_cores", return_value=ret_val) as mock_get_cores:
-            assert sstbf.get_std_cores() == None
+            assert sstbf.get_std_cores() is None
 
     sstbf.STD_CORES = None
     with mock.patch("pwr.get_cores", side_effect = IOError('Test')) as mock_get_cores:
-        assert sstbf.get_std_cores() == None
+        assert sstbf.get_std_cores() is None
         mock_get_cores.assert_called_once()
 
 
 def test_init_sstbf():
+    """
+    Tests sstbf.init_sstbf()
+    """
     for cfgd_value in [True, False]:
-        with mock.patch("common.CONFIG_STORE.get_config", return_value={'sstbf' : {'configured' : cfgd_value}}) as mock_get_cfg,\
-             mock.patch("sstbf.configure_sstbf", return_value=0) as mock_cfg,\
-             mock.patch("sstbf._populate_cores") as mock_populate:
+        with mock.patch("appqos.sstbf.configure_sstbf", return_value=0) as mock_cfg,\
+             mock.patch("appqos.sstbf._populate_cores") as mock_populate:
 
-             assert 0 == sstbf.init_sstbf()
-             mock_get_cfg.assert_called_once()
-             mock_cfg.assert_called_once_with(cfgd_value)
-             mock_populate.assert_called_once()
+            cfg = Config({'sstbf' : {'configured' : cfgd_value}})
+
+            assert 0 == sstbf.init_sstbf(cfg)
+            mock_cfg.assert_called_once_with(cfgd_value)
+            mock_populate.assert_called_once()
