@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -36,14 +36,15 @@
  *
  */
 
+#include "pqos.h"
+
+#include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
-#include <sys/types.h>
 #include <sys/stat.h>
-#include <signal.h>
-#include "pqos.h"
+#include <sys/types.h>
+#include <unistd.h>
 
 /**
  * Defines
@@ -69,10 +70,8 @@ static enum pqos_mon_event sel_events_max = (enum pqos_mon_event)0;
  */
 static struct {
         unsigned core;
-        struct pqos_mon_data *pgrp;
         enum pqos_mon_event events;
 } sel_monitor_core_tab[PQOS_MAX_CORES];
-static struct pqos_mon_data *m_mon_grps[PQOS_MAX_CORES];
 
 /**
  * Maintains a table of process id, event, number of events that are selected
@@ -80,10 +79,11 @@ static struct pqos_mon_data *m_mon_grps[PQOS_MAX_CORES];
  */
 static struct {
         pid_t pid;
-        struct pqos_mon_data *pgrp;
         enum pqos_mon_event events;
 } sel_monitor_pid_tab[PQOS_MAX_PIDS];
 
+static struct pqos_mon_data *m_mon_grps[PQOS_MAX_CORES];
+
 /**
  * Maintains the number of process id's you want to track
  */
@@ -200,8 +200,6 @@ monitoring_get_input(int argc, char *argv[])
                         if (num_args > PQOS_MAX_PIDS)
                                 num_args = PQOS_MAX_PIDS;
                         for (i = 0; i < num_args; i++) {
-                                m_mon_grps[i] = malloc(sizeof(**m_mon_grps));
-                                sel_monitor_pid_tab[i].pgrp = m_mon_grps[i];
                                 sel_monitor_pid_tab[i].pid =
                                     (unsigned)atoi(argv[num_opts + i]);
                         }
@@ -210,8 +208,6 @@ monitoring_get_input(int argc, char *argv[])
                         if (num_args > PQOS_MAX_CORES)
                                 num_args = PQOS_MAX_CORES;
                         for (i = 0; i < num_args; i++) {
-                                m_mon_grps[i] = malloc(sizeof(**m_mon_grps));
-                                sel_monitor_core_tab[i].pgrp = m_mon_grps[i];
                                 sel_monitor_core_tab[i].core =
                                     (unsigned)atoi(argv[num_opts + i]);
                         }
@@ -236,13 +232,23 @@ setup_monitoring(const struct pqos_cpuinfo *cpu_info,
 {
         unsigned i;
         const enum pqos_mon_event perf_events = (enum pqos_mon_event)(
-            PQOS_PERF_EVENT_IPC | PQOS_PERF_EVENT_LLC_MISS);
+            PQOS_PERF_EVENT_IPC | PQOS_PERF_EVENT_LLC_MISS |
+            PQOS_PERF_EVENT_LLC_REF);
+
+        const enum pqos_mon_event uncore_events =
+            (enum pqos_mon_event)(PQOS_PERF_EVENT_LLC_MISS_PCIE_READ |
+                                  PQOS_PERF_EVENT_LLC_MISS_PCIE_WRITE |
+                                  PQOS_PERF_EVENT_LLC_REF_PCIE_READ |
+                                  PQOS_PERF_EVENT_LLC_REF_PCIE_WRITE);
 
         for (i = 0; (unsigned)i < cap_mon->u.mon->num_events; i++)
                 sel_events_max |= (cap_mon->u.mon->events[i].type);
 
         /* Remove perf events IPC and LLC MISSES */
         sel_events_max &= ~perf_events;
+        /* Remove uncore events */
+        sel_events_max &= ~uncore_events;
+
         if (sel_monitor_num == 0 && sel_process_num == 0) {
                 for (i = 0; i < cpu_info->num_cores; i++) {
                         unsigned lcore = cpu_info->cores[i].lcore;
@@ -252,8 +258,6 @@ setup_monitoring(const struct pqos_cpuinfo *cpu_info,
                             sel_events_max;
                         m_mon_grps[sel_monitor_num] =
                             malloc(sizeof(**m_mon_grps));
-                        sel_monitor_core_tab[sel_monitor_num].pgrp =
-                            m_mon_grps[sel_monitor_num];
                         sel_monitor_num++;
                 }
         }
@@ -262,8 +266,8 @@ setup_monitoring(const struct pqos_cpuinfo *cpu_info,
                         unsigned lcore = sel_monitor_core_tab[i].core;
                         int ret;
 
-                        ret = pqos_mon_start(1, &lcore, sel_events_max, NULL,
-                                             sel_monitor_core_tab[i].pgrp);
+                        ret = pqos_mon_start_cores(1, &lcore, sel_events_max,
+                                                   NULL, &m_mon_grps[i]);
                         if (ret != PQOS_RETVAL_OK) {
                                 printf("Monitoring start error on core %u,"
                                        "status %d\n",
@@ -276,9 +280,9 @@ setup_monitoring(const struct pqos_cpuinfo *cpu_info,
                         pid_t pid = sel_monitor_pid_tab[i].pid;
                         int ret;
 
-                        ret = pqos_mon_start_pids(1, &pid,
-                                                  PQOS_MON_EVENT_L3_OCCUP, NULL,
-                                                  sel_monitor_pid_tab[i].pgrp);
+                        ret = pqos_mon_start_pids2(1, &pid,
+                                                   PQOS_MON_EVENT_L3_OCCUP,
+                                                   NULL, &m_mon_grps[i]);
                         if (ret != PQOS_RETVAL_OK) {
                                 printf("Monitoring start error on pid %u,"
                                        "status %d\n",
@@ -310,7 +314,6 @@ stop_monitoring(void)
                 ret = pqos_mon_stop(m_mon_grps[i]);
                 if (ret != PQOS_RETVAL_OK)
                         printf("Monitoring stop error!\n");
-                free(m_mon_grps[i]);
         }
 }
 
@@ -322,7 +325,7 @@ monitoring_loop(void)
 {
         unsigned mon_number = 0;
         int ret = PQOS_RETVAL_OK;
-        int i = 0;
+        int i;
 
         if (signal(SIGINT, monitoring_ctrlc) == SIG_ERR)
                 printf("Failed to catch SIGINT!\n");
