@@ -294,6 +294,54 @@ cap_mba_discover(struct pqos_cap_mba **r_cap,
         return ret;
 }
 
+/**
+ * @brief Discovers support of SMBA
+ *
+ * @param[out] r_cap place to store SMBA capabilities structure
+ * @param[in] cpu detected cpu topology
+ * @param[in] iface Selected interface
+ *
+ * @return Operation status
+ * @retval PQOS_RETVAL_OK success
+ */
+static int
+cap_smba_discover(struct pqos_cap_mba **r_cap,
+                  const struct pqos_cpuinfo *cpu,
+                  const enum pqos_interface iface)
+{
+        struct pqos_cap_mba *cap = NULL;
+        int ret = PQOS_RETVAL_OK;
+
+        cap = (struct pqos_cap_mba *)malloc(sizeof(*cap));
+        if (cap == NULL)
+                return PQOS_RETVAL_RESOURCE;
+
+        switch (iface) {
+        case PQOS_INTER_MSR:
+                if (cpu->vendor == PQOS_VENDOR_AMD)
+                        ret = amd_cap_smba_discover(cap, cpu);
+                else
+                        ret = PQOS_RETVAL_RESOURCE;
+                break;
+#ifdef __linux__
+        case PQOS_INTER_OS:
+        case PQOS_INTER_OS_RESCTRL_MON:
+                ret = os_cap_smba_discover(cap, cpu);
+                break;
+#endif
+        default:
+                ret = PQOS_RETVAL_RESOURCE;
+                break;
+        }
+
+        if (ret == PQOS_RETVAL_OK)
+                *r_cap = cap;
+        else
+                free(cap);
+
+        return ret;
+}
+
 /**
  * @brief Runs detection of platform monitoring and allocation capabilities
  *
@@ -313,6 +361,7 @@ discover_capabilities(struct pqos_cap **p_cap,
         struct pqos_cap_l3ca *det_l3ca = NULL;
         struct pqos_cap_l2ca *det_l2ca = NULL;
         struct pqos_cap_mba *det_mba = NULL;
+        struct pqos_cap_mba *det_smba = NULL;
         struct pqos_cap *_cap = NULL;
         unsigned sz = 0;
         int ret = PQOS_RETVAL_RESOURCE;
@@ -420,6 +469,29 @@ discover_capabilities(struct pqos_cap **p_cap,
                 goto error_exit;
         }
 
+        /**
+         * Slow Memory bandwidth allocation init
+         */
+        ret = cap_smba_discover(&det_smba, cpu, inter);
+        switch (ret) {
+        case PQOS_RETVAL_OK:
+                LOG_INFO("SMBA capability detected\n");
+                LOG_INFO("SMBA details: "
+                         "#COS=%u, %slinear, max=%u, step=%u\n",
+                         det_smba->num_classes,
+                         det_smba->is_linear ? "" : "non-",
+                         det_smba->throttle_max, det_smba->throttle_step);
+                sz += sizeof(struct pqos_capability);
+                break;
+        case PQOS_RETVAL_RESOURCE:
+                LOG_INFO("SMBA capability not detected\n");
+                break;
+        default:
+                LOG_ERROR("Fatal error encounter in SMBA discovery!\n");
+                ret = PQOS_RETVAL_ERROR;
+                goto error_exit;
+        }
+
         if (sz == 0) {
                 LOG_ERROR("No Platform QoS capability discovered\n");
                 ret = PQOS_RETVAL_ERROR;
@@ -478,6 +550,13 @@ discover_capabilities(struct pqos_cap **p_cap,
 #endif
         }
 
+        if (det_smba != NULL) {
+                _cap->capabilities[_cap->num_cap].type = PQOS_CAP_TYPE_SMBA;
+                _cap->capabilities[_cap->num_cap].u.smba = det_smba;
+                _cap->num_cap++;
+                ret = PQOS_RETVAL_OK;
+        }
+
         (*p_cap) = _cap;
 
 error_exit:
@@ -673,6 +752,17 @@ pqos_init(const struct pqos_config *config)
                 goto cpuinfo_init_error;
         }
 
+        if (hw_detect_hybrid())
+                LOG_WARN(
+                    "Hybrid part with L2 CAT support detected.\n"
+                    "      L2 CAT on hybrid parts is not yet supported in "
+                    "pqos\n"
+                    "      tools and may not behave as expected and cause\n"
+                    "      performance degradation. For more information, "
+                    "see:\n"
+                    "      "
+                    "https://github.com/intel/intel-cmt-cat/issues/272\n");
+
 #ifdef __linux__
         if (interface == PQOS_INTER_OS ||
             interface == PQOS_INTER_OS_RESCTRL_MON) {
@@ -1176,6 +1266,52 @@ _pqos_get_sysconfig(void)
         return &m_sysconf;
 }
 
+void
+_pqos_cap_smba_change(const enum pqos_mba_config cfg)
+{
+        struct pqos_cap_mba *smba_cap = NULL;
+        unsigned i;
+#ifdef __linux__
+        enum pqos_interface interface = _pqos_get_inter();
+#endif
+        ASSERT(cfg == PQOS_MBA_DEFAULT || cfg == PQOS_MBA_CTRL ||
+               cfg == PQOS_MBA_ANY);
+        ASSERT(m_sysconf.cap != NULL);
+
+        if (m_sysconf.cap == NULL)
+                return;
+
+        for (i = 0; i < m_sysconf.cap->num_cap && smba_cap == NULL; i++)
+                if (m_sysconf.cap->capabilities[i].type == PQOS_CAP_TYPE_SMBA)
+                        smba_cap = m_sysconf.cap->capabilities[i].u.smba;
+
+        if (smba_cap == NULL)
+                return;
+
+#ifdef __linux__
+        /* refresh number of classes */
+        if (interface == PQOS_INTER_OS ||
+            interface == PQOS_INTER_OS_RESCTRL_MON) {
+                int ret;
+                unsigned num_classes;
+
+                ret = resctrl_alloc_get_num_closids(&num_classes);
+                if (ret == PQOS_RETVAL_OK)
+                        smba_cap->num_classes = num_classes;
+        }
+#endif
+
+        if (cfg == PQOS_MBA_DEFAULT)
+                smba_cap->ctrl_on = 0;
+        else if (cfg == PQOS_MBA_CTRL) {
+#ifdef __linux__
+                if (interface != PQOS_INTER_MSR)
+                        smba_cap->ctrl = 1;
+#endif
+                smba_cap->ctrl_on = 1;
+        }
+}
+
 const struct pqos_cap *
 _pqos_get_cap(void)
 {
