@@ -54,6 +54,17 @@ extern "C" {
  */
 PQOS_LOCAL int hw_cap_mon_iordt(const struct pqos_cpuinfo *cpu, int *enabled);
 
+/**
+ * @brief Detects if the platform has hybrid architecture
+ *
+ * Runs CPUID instruction and return bit shows the platorm
+ * hybrid status. For example whether the platform has both
+ * P-cores and E-cores on board.
+ *
+ * @return 1 if the platform is a hybrid one, 0 - otherwise
+ */
+PQOS_LOCAL int hw_detect_hybrid(void);
+
 /**
  * @brief Discovers HW monitoring support
  *
@@ -158,6 +169,18 @@ PQOS_LOCAL int hw_cap_mba_discover(struct pqos_cap_mba *cap,
  */
 PQOS_LOCAL int amd_cap_mba_discover(struct pqos_cap_mba *cap,
                                     const struct pqos_cpuinfo *cpu);
+/**
+ * @brief Discovers SMBA support for AMD
+ *
+ * @param cap place to store SMBA capabilities
+ * @param cpu detected cpu topology
+ *
+ * @return Operation status
+ * @retval PQOS_RETVAL_OK success
+ * @retval PQOS_RETVAL_RESOURCE if not supported
+ */
+PQOS_LOCAL int amd_cap_smba_discover(struct pqos_cap_mba *cap,
+                                     const struct pqos_cpuinfo *cpu);
 
 #ifdef __cplusplus
 }
