@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -35,22 +35,21 @@
  * @brief Library operations logger for info, warnings and errors.
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <string.h>
-#include <unistd.h>
-#include <errno.h>
+#include "log.h"
 
 #include "types.h"
-#include "log.h"
+
+#include <errno.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
 
 /**
  * ---------------------------------------
  * Local data types
  * ---------------------------------------
  */
-#define AP_BUFFER_SIZE 256
+#define AP_BUFFER_SIZE 320
 
 /**
  * ---------------------------------------
