@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2018-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2018-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -42,9 +42,12 @@
 extern "C" {
 #endif
 
+#include "pqos.h"
 #include "types.h"
 
-#define PERF_MON_PATH "/sys/devices/intel_cqm"
+#define PERF_MON_PATH   "/sys/devices/intel_cqm"
+#define PERF_MON_TYPE   "/sys/devices/intel_cqm/type"
+#define PERF_MON_EVENTS "/sys/devices/intel_cqm/events"
 
 /**
  * Local monitor event types
