@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2018-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2018-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -31,22 +31,21 @@
  *
  */
 
-#include <stdlib.h>
-#include <unistd.h>
-#include <sys/file.h>
-#include <signal.h>
-#include <sys/mount.h>
-#include <errno.h>
-#include <string.h>
-#include <fcntl.h>
-
-#include "pqos.h"
-#include "log.h"
-#include "types.h"
 #include "resctrl.h"
+
 #include "common.h"
+#include "log.h"
 #include "os_common.h"
 
+#include <errno.h>
+#include <fcntl.h>
+#include <signal.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/file.h>
+#include <sys/mount.h>
+#include <unistd.h>
+
 static int resctrl_lock_fd = -1; /**< File descriptor to the lockfile */
 
 /**
@@ -62,7 +61,7 @@ resctrl_lock_signalhandler(int signal)
 /**
  * @brief Obtain lock on resctrl filesystem
  *
- * @param[in] type type of lock
+ * @param[in] type lock type
  *
  * @return Operational status
  * @retval PQOS_RETVAL_OK on success
@@ -178,8 +177,10 @@ resctrl_mount(const enum pqos_cdp_config l3_cdp_cfg,
                 options = buf;
         }
 
-        if (mount("resctrl", RESCTRL_PATH, "resctrl", 0, options) != 0)
+        if (mount("resctrl", RESCTRL_PATH, "resctrl", 0, options) != 0) {
+                LOG_DEBUG("resctrl mount failed with error %d - %m\n", errno);
                 return PQOS_RETVAL_ERROR;
+        }
 
         return PQOS_RETVAL_OK;
 }
@@ -343,7 +344,7 @@ resctrl_is_supported(void)
                                    "Kernel version 4.10 or higher required");
 
         if (resctrl == 0)
-                return PQOS_RETVAL_ERROR;
+                return PQOS_RETVAL_RESOURCE;
 
         return PQOS_RETVAL_OK;
 }
