@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2022 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -74,4 +74,8 @@ extern "C" {
 #define PQOS_LOCAL
 #endif
 
+#ifndef PQOS_STATIC
+#define PQOS_STATIC static
+#endif
+
 #endif /* __PQOS_TYPES_H__ */
