@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2022 Intel Corporation. All rights reserved.
+ * Copyright(c) 2022-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -35,6 +35,7 @@
 
 #include "cap.h"
 #include "cpu_registers.h"
+#include "cpuinfo.h"
 #include "log.h"
 #include "machine.h"
 #include "monitoring.h"
@@ -67,8 +68,6 @@
 
 #define UNCORE_CHA_MAX 40
 
-#define CPU_MODEL_SKX 0x55
-
 /** uncore channels */
 static uint64_t m_uncore_cha = 0;
 
@@ -176,27 +175,6 @@ filter_cha(const struct dirent *dir)
         return fnmatch(UNCORE_CHA "[0-9]*", dir->d_name, 0) == 0;
 }
 
-/**
- * @brief Detect cpu model
- *
- * @return detected cpu model
- */
-static uint32_t
-_get_cpu_model(void)
-{
-        uint32_t model;
-        struct cpuid_out out;
-
-        lcpuid(1, 0, &out);
-
-        /* Read CPU model */
-        model = (out.eax & 0xf0) >> 4;
-        /* Read CPU extended model */
-        model |= (out.eax & 0xf0000) >> 12;
-
-        return model;
-}
-
 /**
  * @brief Discover uncore monitoring events
  *
@@ -208,7 +186,7 @@ _get_cpu_model(void)
 int
 uncore_mon_discover(enum pqos_mon_event *event)
 {
-        uint32_t model = _get_cpu_model();
+        uint32_t model = cpuinfo_get_cpu_model();
 
         if (model == CPU_MODEL_SKX)
                 *event =
@@ -251,7 +229,7 @@ uncore_mon_init(const struct pqos_cpuinfo *cpu, const struct pqos_cap *cap)
         UNUSED_PARAM(cpu);
 
         {
-                uint32_t model = _get_cpu_model();
+                uint32_t model = cpuinfo_get_cpu_model();
 
                 if (model == CPU_MODEL_SKX) {
                         uncore_events = uncore_events_skx;
@@ -300,6 +278,11 @@ uncore_mon_init(const struct pqos_cpuinfo *cpu, const struct pqos_cap *cap)
 int
 uncore_mon_fini(void)
 {
+        m_uncore_cha = 0;
+        all_evt_mask = (enum pqos_mon_event)0;
+        uncore_events = NULL;
+        uncore_unit_ctrl = NULL;
+
         return PQOS_RETVAL_OK;
 }
 
@@ -316,8 +299,7 @@ static int
 _setup_counter(unsigned lcore, enum pqos_mon_event event)
 {
         int ret = PQOS_RETVAL_OK;
-        struct uncore_mon_event *evt =
-            get_event(PQOS_PERF_EVENT_LLC_MISS_PCIE_READ);
+        struct uncore_mon_event *evt = get_event(event);
         uint32_t reg_unit_ctrl;
         uint32_t reg_ctrl;
         uint32_t reg_filter1;
@@ -356,12 +338,12 @@ _setup_counter(unsigned lcore, enum pqos_mon_event event)
                 return PQOS_RETVAL_PARAM;
         }
 
-        /* unfreeze conters */
+        /* unfreeze counters */
         ret = msr_write(lcore, reg_unit_ctrl, UNIT_CTRL_UNFREEZE_COUNTER);
         if (ret != MACHINE_RETVAL_OK)
                 return PQOS_RETVAL_ERROR;
 
-        /* freeze conters */
+        /* freeze conuters */
         ret = msr_write(lcore, reg_unit_ctrl, UNIT_CTRL_FREEZE_COUNTER);
         if (ret != MACHINE_RETVAL_OK)
                 return PQOS_RETVAL_ERROR;
@@ -392,7 +374,7 @@ _setup_counter(unsigned lcore, enum pqos_mon_event event)
         if (ret != MACHINE_RETVAL_OK)
                 return PQOS_RETVAL_ERROR;
 
-        /* unfreeze conters */
+        /* unfreeze counters */
         ret = msr_write(lcore, reg_unit_ctrl, UNIT_CTRL_UNFREEZE_COUNTER);
         if (ret != MACHINE_RETVAL_OK)
                 return PQOS_RETVAL_ERROR;
@@ -403,7 +385,7 @@ _setup_counter(unsigned lcore, enum pqos_mon_event event)
 int
 uncore_mon_start(struct pqos_mon_data *group, enum pqos_mon_event event)
 {
-        int ret;
+        int ret = PQOS_RETVAL_OK;
         unsigned s;
         const struct pqos_cpuinfo *cpu = _pqos_get_cpu();
 
@@ -420,15 +402,15 @@ uncore_mon_start(struct pqos_mon_data *group, enum pqos_mon_event event)
                         if ((event & uncore_event_map[i]) == 0)
                                 continue;
 
-                        ret = _setup_counter(lcore, event);
-                        if (ret != PQOS_RETVAL_ERROR)
+                        ret = _setup_counter(lcore, uncore_event_map[i]);
+                        if (ret != PQOS_RETVAL_OK)
                                 break;
                 }
         }
 
         group->intl->hw.event |= (enum pqos_mon_event)(event & all_evt_mask);
 
-        return PQOS_RETVAL_OK;
+        return ret;
 }
 
 int
