@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2019-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2019-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -42,7 +42,27 @@
 extern "C" {
 #endif
 
+#ifdef DEBUG
+#include <assert.h>
+#endif
+
 #include <stdio.h>
+#include <sys/stat.h>
+
+#ifdef DEBUG
+#define ASSERT assert
+#else
+#define ASSERT(x)
+#endif
+
+/**
+ * Macros
+ */
+#ifndef DIM
+#define DIM(x) (sizeof(x) / sizeof(x[0]))
+#endif
+
+#define UNUSED_ARG(_x) ((void)(_x))
 
 /**
  * @brief Wrapper around fopen() that additionally checks if a given path
@@ -55,7 +75,9 @@ extern "C" {
  * @retval A valid pointer to a file or NULL on error (e.g. when the path
  * contains any symbolic links).
  */
-FILE * safe_fopen(const char *name, const char *mode);
+/* clang-format off */
+FILE *safe_fopen(const char *name, const char *mode);
+/* clang-format on */
 
 /**
  * @brief Wrapper around open() that additionally checks if a given path
@@ -71,6 +93,16 @@ FILE * safe_fopen(const char *name, const char *mode);
  */
 int safe_open(const char *pathname, int flags, mode_t mode);
 
+/**
+ * @brief Common function to handle string parsing errors
+ *
+ * On error, this function causes process to exit with FAILURE code.
+ *
+ * @param arg string that caused error when parsing
+ * @param note context and information about encountered error
+ */
+void parse_error(const char *arg, const char *note) __attribute__((noreturn));
+
 #ifdef __cplusplus
 }
 #endif
