@@ -1,7 +1,7 @@
 ################################################################################
 # BSD LICENSE
 #
-# Copyright(c) 2019-2021 Intel Corporation. All rights reserved.
+# Copyright(c) 2019-2023 Intel Corporation. All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -126,17 +126,17 @@ class TestPqosL3Cat(test.Test):
     #  \b Priority: High
     #
     #  \b Objective:
-    #  Unable to set up allocation COS with a bitmask more than 28 bits
+    #  Unable to set up allocation COS with a bitmask more than 32 bits
     #
     #  \b Instruction:
-    #  Run "pqos [-I] -e llc:2=0xffffffff" to set the COS bitmask which is more than 28 bits.
+    #  Run "pqos [-I] -e llc:2=0xfffffffff" to set the COS bitmask which is more than 32 bits.
     #
     #  \b Result:
     #  Observe "SOCKET 0 L3CA COS2 - FAILED!" and "Allocation configuration error!" in output
     @PRIORITY_HIGH
     @pytest.mark.rdt_supported("cat_l3")
     def test_pqos_l3cat_set_negative(self, iface):
-        (stdout, _, exitstatus) = self.run_pqos(iface, "-e llc:2=0xffffffff")
+        (stdout, _, exitstatus) = self.run_pqos(iface, "-e llc:2=0xfffffffff")
         assert exitstatus == 1
         assert "SOCKET 0 L3CA COS2 - FAILED" in stdout
         assert "Allocation configuration error!" in stdout
@@ -370,7 +370,7 @@ class TestPqosL3Cat(test.Test):
 
         (stdout, _, exitstatus) = self.run_pqos(iface, "-e llc:4c=0xf")
         assert exitstatus == 0
-        assert ("SOCKET 0 L3CA COS4 => DATA {},CODE 0xf").format(hex(default_mask)) in stdout
+        assert f"SOCKET 0 L3CA COS4 => DATA {hex(default_mask)},CODE 0xf" in stdout
 
 
     ## PQOS - L3 CDP Set COS definition - Data only
@@ -395,4 +395,4 @@ class TestPqosL3Cat(test.Test):
 
         (stdout, _, exitstatus) = self.run_pqos(iface, "-e llc:3d=0xf")
         assert exitstatus == 0
-        assert ("SOCKET 0 L3CA COS3 => DATA 0xf,CODE {}").format(hex(default_mask)) in stdout
+        assert f"SOCKET 0 L3CA COS3 => DATA 0xf,CODE {hex(default_mask)}" in stdout
