@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,15 +30,9 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <string.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
-
 #include "allocation.h"
 #include "cpu_registers.h"
+#include "test.h"
 
 /* ======== hw_alloc_assoc_write ======== */
 
@@ -51,8 +45,8 @@ test_hw_alloc_assoc_write(void **state __attribute__((unused)))
 
         expect_value(__wrap_msr_read, lcore, lcore);
         expect_value(__wrap_msr_read, reg, PQOS_MSR_ASSOC);
-        will_return(__wrap_msr_read, 0);
         will_return(__wrap_msr_read, PQOS_RETVAL_OK);
+        will_return(__wrap_msr_read, 0);
 
         expect_value(__wrap_msr_write, lcore, lcore);
         expect_value(__wrap_msr_write, reg, PQOS_MSR_ASSOC);
@@ -73,7 +67,6 @@ test_hw_alloc_assoc_write_error_read(void **state __attribute__((unused)))
 
         expect_value(__wrap_msr_read, lcore, lcore);
         expect_value(__wrap_msr_read, reg, PQOS_MSR_ASSOC);
-        will_return(__wrap_msr_read, 0);
         will_return(__wrap_msr_read, PQOS_RETVAL_ERROR);
 
         ret = hw_alloc_assoc_write(lcore, class_id);
@@ -89,8 +82,8 @@ test_hw_alloc_assoc_write_error_write(void **state __attribute__((unused)))
 
         expect_value(__wrap_msr_read, lcore, lcore);
         expect_value(__wrap_msr_read, reg, PQOS_MSR_ASSOC);
-        will_return(__wrap_msr_read, 0);
         will_return(__wrap_msr_read, PQOS_RETVAL_OK);
+        will_return(__wrap_msr_read, 0);
 
         expect_value(__wrap_msr_write, lcore, lcore);
         expect_value(__wrap_msr_write, reg, PQOS_MSR_ASSOC);
@@ -115,4 +108,4 @@ main(void)
         result += cmocka_run_group_tests(tests, NULL, NULL);
 
         return result;
-}
\ No newline at end of file
+}
