@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,16 +30,8 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <string.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
-
-#include "test.h"
-
 #include "hw_cap.h"
+#include "test.h"
 
 /* ======== hw_cap_l2ca_cdp ======== */
 
@@ -59,8 +51,8 @@ test_hw_cap_l2ca_cdp_enabled(void **state)
         for (i = 0; i < l2id_num; ++i) {
                 expect_any(__wrap_msr_read, lcore);
                 expect_value(__wrap_msr_read, reg, PQOS_MSR_L2_QOS_CFG);
-                will_return(__wrap_msr_read, PQOS_MSR_L2_QOS_CFG_CDP_EN);
                 will_return(__wrap_msr_read, PQOS_RETVAL_OK);
+                will_return(__wrap_msr_read, PQOS_MSR_L2_QOS_CFG_CDP_EN);
         }
 
         ret = hw_cap_l2ca_cdp(data->cpu, &enabled);
@@ -86,8 +78,8 @@ test_hw_cap_l2ca_cdp_disabled(void **state)
         for (i = 0; i < l2id_num; ++i) {
                 expect_any(__wrap_msr_read, lcore);
                 expect_value(__wrap_msr_read, reg, PQOS_MSR_L2_QOS_CFG);
-                will_return(__wrap_msr_read, 0);
                 will_return(__wrap_msr_read, PQOS_RETVAL_OK);
+                will_return(__wrap_msr_read, 0);
         }
 
         ret = hw_cap_l2ca_cdp(data->cpu, &enabled);
@@ -113,12 +105,12 @@ test_hw_cap_l2ca_cdp_conflict(void **state)
         for (i = 0; i < l2id_num; ++i) {
                 expect_any(__wrap_msr_read, lcore);
                 expect_value(__wrap_msr_read, reg, PQOS_MSR_L2_QOS_CFG);
+                will_return(__wrap_msr_read, PQOS_RETVAL_OK);
                 if (i == 1)
                         will_return(__wrap_msr_read, 0);
                 else
                         will_return(__wrap_msr_read,
                                     PQOS_MSR_L2_QOS_CFG_CDP_EN);
-                will_return(__wrap_msr_read, PQOS_RETVAL_OK);
         }
 
         ret = hw_cap_l2ca_cdp(data->cpu, &enabled);
@@ -156,4 +148,4 @@ main(void)
             cmocka_run_group_tests(tests, test_init_unsupported, test_fini);
 
         return result;
-}
\ No newline at end of file
+}
