@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,15 +30,9 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <string.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
-
-#include "hw_monitoring.h"
 #include "cpu_registers.h"
+#include "hw_monitoring.h"
+#include "test.h"
 
 /* ======== hw_mon_assoc_read ======== */
 
@@ -51,8 +45,8 @@ test_hw_mon_assoc_read(void **state __attribute__((unused)))
 
         expect_value(__wrap_msr_read, lcore, lcore);
         expect_value(__wrap_msr_read, reg, PQOS_MSR_ASSOC);
-        will_return(__wrap_msr_read, 2);
         will_return(__wrap_msr_read, PQOS_RETVAL_OK);
+        will_return(__wrap_msr_read, 2);
 
         ret = hw_mon_assoc_read(lcore, &rmid);
         assert_int_equal(ret, PQOS_RETVAL_OK);
@@ -68,7 +62,6 @@ test_hw_mon_assoc_read_error(void **state __attribute__((unused)))
 
         expect_value(__wrap_msr_read, lcore, lcore);
         expect_value(__wrap_msr_read, reg, PQOS_MSR_ASSOC);
-        will_return(__wrap_msr_read, 2);
         will_return(__wrap_msr_read, PQOS_RETVAL_ERROR);
 
         ret = hw_mon_assoc_read(lcore, &rmid);
@@ -88,4 +81,4 @@ main(void)
         result += cmocka_run_group_tests(tests, NULL, NULL);
 
         return result;
-}
\ No newline at end of file
+}
