@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,15 +30,9 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <string.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
-
 #include "hw_monitoring.h"
 #include "perf_monitoring.h"
+#include "test.h"
 
 static void
 test_hw_mon_start_perf(void **state __attribute__((unused)))
@@ -51,6 +45,7 @@ test_hw_mon_start_perf(void **state __attribute__((unused)))
             PQOS_PERF_EVENT_CYCLES | PQOS_PERF_EVENT_IPC;
         int ret;
 
+        memset(&intl, 0, sizeof(intl));
         memset(&group, 0, sizeof(struct pqos_mon_data));
         group.intl = &intl;
         group.num_cores = num_cores;
@@ -85,4 +80,4 @@ main(void)
         result += cmocka_run_group_tests(tests, NULL, NULL);
 
         return result;
-}
\ No newline at end of file
+}
