@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,20 +30,12 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <string.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
-
-#include "test.h"
 #include "mock_cap.h"
 #include "mock_resctrl.h"
 #include "mock_resctrl_alloc.h"
 #include "mock_resctrl_monitoring.h"
-
 #include "os_allocation.h"
+#include "test.h"
 
 /* ======== os_alloc_assoc_set ======== */
 
@@ -55,8 +47,8 @@ test_os_alloc_assoc_set(void **state)
         unsigned class_id = 1;
         unsigned lcore = 2;
 
-        will_return(__wrap__pqos_cap_get, data->cap);
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         will_return(__wrap_resctrl_lock_exclusive, PQOS_RETVAL_OK);
         will_return(__wrap_resctrl_lock_release, PQOS_RETVAL_OK);
@@ -80,8 +72,8 @@ test_os_alloc_assoc_set_active_mon(void **state)
         unsigned class_id = 1;
         unsigned lcore = 2;
 
-        will_return(__wrap__pqos_cap_get, data->cap);
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         will_return(__wrap_resctrl_lock_exclusive, PQOS_RETVAL_OK);
         will_return(__wrap_resctrl_lock_release, PQOS_RETVAL_OK);
@@ -94,6 +86,7 @@ test_os_alloc_assoc_set_active_mon(void **state)
         will_return(__wrap_resctrl_alloc_assoc_set, PQOS_RETVAL_OK);
 
         expect_value(__wrap_resctrl_mon_assoc_set, lcore, lcore);
+        expect_string(__wrap_resctrl_mon_assoc_set, name, "test");
         will_return(__wrap_resctrl_mon_assoc_set, PQOS_RETVAL_OK);
 
         ret = os_alloc_assoc_set(lcore, class_id);
@@ -108,15 +101,12 @@ test_os_alloc_assoc_set_param(void **state)
         unsigned class_id = 1;
         unsigned lcore = 2;
 
-        will_return(__wrap__pqos_cap_get, data->cap);
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         ret = os_alloc_assoc_set(1000, class_id);
         assert_int_equal(ret, PQOS_RETVAL_PARAM);
 
-        will_return(__wrap__pqos_cap_get, data->cap);
-        will_return(__wrap__pqos_cap_get, data->cpu);
-
         ret = os_alloc_assoc_set(lcore, 100);
         assert_int_equal(ret, PQOS_RETVAL_PARAM);
 }
@@ -131,7 +121,8 @@ test_os_alloc_assoc_set_pid(void **state)
         unsigned class_id = 1;
         pid_t task = 2;
 
-        will_return(__wrap__pqos_cap_get, data->cap);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         will_return(__wrap_resctrl_lock_exclusive, PQOS_RETVAL_OK);
         will_return(__wrap_resctrl_lock_release, PQOS_RETVAL_OK);
@@ -155,7 +146,8 @@ test_os_alloc_assoc_set_pid_active_mon(void **state)
         unsigned class_id = 1;
         pid_t task = 2;
 
-        will_return(__wrap__pqos_cap_get, data->cap);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         will_return(__wrap_resctrl_lock_exclusive, PQOS_RETVAL_OK);
         will_return(__wrap_resctrl_lock_release, PQOS_RETVAL_OK);
@@ -168,6 +160,7 @@ test_os_alloc_assoc_set_pid_active_mon(void **state)
         will_return(__wrap_resctrl_alloc_assoc_set_pid, PQOS_RETVAL_OK);
 
         expect_value(__wrap_resctrl_mon_assoc_set_pid, task, task);
+        expect_string(__wrap_resctrl_mon_assoc_set_pid, name, "test");
         will_return(__wrap_resctrl_mon_assoc_set_pid, PQOS_RETVAL_OK);
 
         ret = os_alloc_assoc_set_pid(task, class_id);
@@ -181,7 +174,8 @@ test_os_alloc_assoc_set_pid_param(void **state)
         int ret;
         pid_t task = 2;
 
-        will_return(__wrap__pqos_cap_get, data->cap);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         ret = os_alloc_assoc_set_pid(task, 100);
         assert_int_equal(ret, PQOS_RETVAL_PARAM);
@@ -216,4 +210,4 @@ main(void)
                                          test_init_unsupported, test_fini);
 
         return result;
-}
\ No newline at end of file
+}
