@@ -201,10 +201,13 @@ static void
 test_os_mon_reset(void **state __attribute__((unused)))
 {
         int ret;
+        struct pqos_mon_config cfg;
+
+        memset(&cfg, 0, sizeof(cfg));
 
         will_return(__wrap_resctrl_mon_reset, PQOS_RETVAL_OK);
 
-        ret = os_mon_reset();
+        ret = os_mon_reset(&cfg);
         assert_int_equal(ret, PQOS_RETVAL_OK);
 }
 
