@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2022 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -35,9 +35,15 @@
 
 #include "common.h"
 
+FILE *__wrap_pqos_fopen(const char *name, const char *mode);
+int __wrap_pqos_fclose(FILE *fd);
+int __real_pqos_fclose(FILE *fd);
+int __wrap_pqos_fread_uint(const char *path, unsigned *value);
 int __wrap_pqos_fread_uint64(const char *fname, unsigned base, uint64_t *value);
 int __wrap_pqos_file_exists(const char *path);
 int __wrap_pqos_dir_exists(const char *path);
 int __wrap_pqos_file_contains(const char *fname, const char *str, int *found);
 
+size_t __wrap_fread(void *ptr, size_t size, size_t nmemb, FILE *stream);
+
 #endif /* MOCK_COMMON_H_ */
