@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,13 +30,10 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
-
 #include "mock_resctrl_alloc.h"
 
+#include "mock_test.h"
+
 int
 __wrap_resctrl_alloc_init(const struct pqos_cpuinfo *cpu,
                           const struct pqos_cap *cap)
@@ -178,4 +175,28 @@ __wrap_resctrl_alloc_get_num_closids(unsigned *num_closids)
                 *num_closids = mock_type(int);
 
         return ret;
-}
\ No newline at end of file
+}
+
+int
+__wrap_resctrl_alloc_get_grps_num(const struct pqos_cap *cap,
+                                  unsigned *grps_num)
+{
+        int ret;
+
+        assert_non_null(cap);
+        assert_non_null(grps_num);
+
+        ret = mock_type(int);
+        if (ret == PQOS_RETVAL_OK)
+                *grps_num = mock_type(int);
+
+        return ret;
+}
+
+int
+__wrap_resctrl_alloc_task_validate(const pid_t task)
+{
+        check_expected(task);
+
+        return mock_type(int);
+}
